<?xml version="1.0"?>
<?xml-stylesheet type="text/xsl" href="/rss.xsl.xml"?>
<rss version="2.0" xmlns:dc="http://purl.org/dc/elements/1.1/">
<channel>
    <title>Changes in algorithm</title>
    <description></description>
    <language>en</language>
    <copyright>Copyright 2015</copyright>
    <generator>Java</generator><item>
        <title>bb8d20d9 - [cuda][hip] Fix typoes in header wrappers.</title>
        <link>http://172.16.0.5:8080/history/llvm-project-15.0.7/clang/lib/Headers/cuda_wrappers/algorithm#bb8d20d9</link>
        <description>[cuda][hip] Fix typoes in header wrappers.

            List of files:
            /llvm-project-15.0.7/clang/lib/Headers/cuda_wrappers/algorithm</description>
        <pubDate>Mon, 21 Dec 2020 18:02:47 +0000</pubDate>
        <dc:creator>Michael Liao &lt;michael.hliao@gmail.com&gt;</dc:creator>
    </item>
<item>
        <title>2a192aba - [CUDA] Make __host__/__device__ min/max overloads constexpr in C++14.</title>
        <link>http://172.16.0.5:8080/history/llvm-project-15.0.7/clang/lib/Headers/cuda_wrappers/algorithm#2a192aba</link>
        <description>[CUDA] Make __host__/__device__ min/max overloads constexpr in C++14.Summary: Tests in a separate change to the test-suite.Reviewers: rsmith, traSubscribers: lahwaacz, sanjoy, cfe-commitsDifferential Revision: https://reviews.llvm.org/D48151llvm-svn: 336026

            List of files:
            /llvm-project-15.0.7/clang/lib/Headers/cuda_wrappers/algorithm</description>
        <pubDate>Fri, 29 Jun 2018 22:28:09 +0000</pubDate>
        <dc:creator>Justin Lebar &lt;jlebar@google.com&gt;</dc:creator>
    </item>
<item>
        <title>5cb41c2a - [CUDA] Make min/max shims host+device.</title>
        <link>http://172.16.0.5:8080/history/llvm-project-15.0.7/clang/lib/Headers/cuda_wrappers/algorithm#5cb41c2a</link>
        <description>[CUDA] Make min/max shims host+device.Summary:Fixes PR37753: min/max can&apos;t be called from __host__ __device__functions in C++14 mode.Testcase in a separate test-suite commit.Reviewers: rsmithSubscribers: sanjoy, lahwaacz, cfe-commitsDifferential Revision: https://reviews.llvm.org/D48036llvm-svn: 336025

            List of files:
            /llvm-project-15.0.7/clang/lib/Headers/cuda_wrappers/algorithm</description>
        <pubDate>Fri, 29 Jun 2018 22:27:56 +0000</pubDate>
        <dc:creator>Justin Lebar &lt;jlebar@google.com&gt;</dc:creator>
    </item>
<item>
        <title>c70121b9 - [CUDA] Make std::min/max work when compiling in C++14 mode with a C++11 stdlib.</title>
        <link>http://172.16.0.5:8080/history/llvm-project-15.0.7/clang/lib/Headers/cuda_wrappers/algorithm#c70121b9</link>
        <description>[CUDA] Make std::min/max work when compiling in C++14 mode with a C++11 stdlib.Reviewers: rsmithSubscribers: sanjoy, cfe-commits, traDifferential Revision: https://reviews.llvm.org/D46993llvm-svn: 332619

            List of files:
            /llvm-project-15.0.7/clang/lib/Headers/cuda_wrappers/algorithm</description>
        <pubDate>Thu, 17 May 2018 16:12:42 +0000</pubDate>
        <dc:creator>Justin Lebar &lt;jlebar@google.com&gt;</dc:creator>
    </item>
<item>
        <title>7c56dfe4 - [CUDA] Fix std::min on device side to return the min, not the max.</title>
        <link>http://172.16.0.5:8080/history/llvm-project-15.0.7/clang/lib/Headers/cuda_wrappers/algorithm#7c56dfe4</link>
        <description>[CUDA] Fix std::min on device side to return the min, not the max.Summary:How embarrassing.This is tested in the test-suite -- fix to come there in a separatepatch.Reviewers: traSubscribers: sanjoy, cfe-commitsDifferential Revision: https://reviews.llvm.org/D39817llvm-svn: 317961

            List of files:
            /llvm-project-15.0.7/clang/lib/Headers/cuda_wrappers/algorithm</description>
        <pubDate>Sat, 11 Nov 2017 01:25:44 +0000</pubDate>
        <dc:creator>Justin Lebar &lt;jlebar@google.com&gt;</dc:creator>
    </item>
<item>
        <title>49ec1469 - [CUDA] Re-land support for &lt;complex&gt; (r283683 and r283680).</title>
        <link>http://172.16.0.5:8080/history/llvm-project-15.0.7/clang/lib/Headers/cuda_wrappers/algorithm#49ec1469</link>
        <description>[CUDA] Re-land support for &lt;complex&gt; (r283683 and r283680).These were reverted in r283753 and r283747.The first patch added a header to the root &apos;Headers&apos; install directory,instead of into &apos;Headers/cuda_wrappers&apos;.  This was fixed in the secondpatch, but by then the damage was done: The bad header stayed in the&apos;Headers&apos; directory, continuing to break the build.We reverted both patches in an attempt to fix things, but that stilldidn&apos;t get rid of the header, so the Windows boostrap build remainedbroken.It&apos;s probably worth fixing up our cmake logic to remove things from theinstall dirs, but in the meantime, re-land these patches, since webelieve they no longer have this bug.llvm-svn: 283907

            List of files:
            /llvm-project-15.0.7/clang/lib/Headers/cuda_wrappers/algorithm</description>
        <pubDate>Tue, 11 Oct 2016 17:36:03 +0000</pubDate>
        <dc:creator>Justin Lebar &lt;jlebar@google.com&gt;</dc:creator>
    </item>
<item>
        <title>d3c5d2a4 - [CUDA] Support &lt;complex&gt; and std::min/max on the device.</title>
        <link>http://172.16.0.5:8080/history/llvm-project-15.0.7/clang/lib/Headers/cuda_wrappers/algorithm#d3c5d2a4</link>
        <description>[CUDA] Support &lt;complex&gt; and std::min/max on the device.Summary:We do this by wrapping &lt;complex&gt; and &lt;algorithm&gt;.Tests are in the test-suite.Reviewers: traSubscribers: jhen, beanz, cfe-commits, mgornyDifferential Revision: https://reviews.llvm.org/D24979llvm-svn: 283680

            List of files:
            /llvm-project-15.0.7/clang/lib/Headers/cuda_wrappers/algorithm</description>
        <pubDate>Sat, 08 Oct 2016 22:16:12 +0000</pubDate>
        <dc:creator>Justin Lebar &lt;jlebar@google.com&gt;</dc:creator>
    </item>
</channel>
</rss>
